@@ -99,7 +99,7 @@ int isoburn_initialize(char msg[1024], int flag)
       error: 'INTENTIONAL_ABORT_OF_COMPILATION__HEADERFILE_libisofs_dot_h_TOO_OLD__SEE_libisoburn_dot_h_AND_burn_wrap_dot_h' undeclared (first use in this function)
       error: 'LIBISOFS_MISCONFIGURATION_' undeclared (first use in this function)
 */
-/* The indendation is an advise of man gcc to help old compilers ignoring */
+/* The indentation is an advise of man gcc to help old compilers ignoring */
  #if isoburn_libisofs_req_major > iso_lib_header_version_major
  #define Isoburn_libisofs_dot_h_too_olD 1
  #endif
@@ -136,7 +136,7 @@ LIBISOFS_MISCONFIGURATION_ = 0;
       error: 'LIBBURN_MISCONFIGURATION_' undeclared (first use in this function)
 */
 
-/* The indendation is an advise of man gcc to help old compilers ignoring */
+/* The indentation is an advise of man gcc to help old compilers ignoring */
  #if isoburn_libburn_req_major > burn_header_version_major
  #define Isoburn_libburn_dot_h_too_olD 1
  #endif
@@ -161,7 +161,7 @@ LIBBURN_MISCONFIGURATION_ = 0;
    So the requirement is defined in libisofs/libisofs.h :
      iso_libjte_req_major , iso_libjte_req_minor , iso_libjte_req_micro
 */
- /* The indendation is an advise of man gcc to help old compilers ignoring */
+ /* The indentation is an advise of man gcc to help old compilers ignoring */
  #if iso_libjte_req_major > LIBJTE_VERSION_MAJOR
  #define Libisofs_libjte_dot_h_too_olD 1
  #endif
@@ -333,10 +333,10 @@ int isoburn_is_intermediate_dvd_rw(struct burn_drive *d, int flag)
 
 
 /** Examines the medium and sets appropriate emulation if needed.
-    @param flag bit0= pretent blank on overwriteable media
+    @param flag bit0= pretent blank on overwritable media
                 bit3= if the drive reports a -ROM profile then try to read 
                       table of content by scanning for ISO image headers.
-                bit4= do not emulate TOC on overwriteable media
+                bit4= do not emulate TOC on overwritable media
                 bit5= ignore ACL from external filesystems
                 bit6= ignore POSIX Extended Attributes from external filesystems
                 bit7= pretend -ROM and scan for table of content
@@ -401,7 +401,7 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
  random_access= caps->start_adr || role == 4;
  if(random_access)
    (*o)->emulation_mode= 1;
- if(random_access && !readonly) {       /* set emulation to overwriteable */
+ if(random_access && !readonly) {       /* set emulation to overwritable */
    ret= isoburn_is_intermediate_dvd_rw(d, 0);
    if(ret>0) {
      (*o)->min_start_byte= 0;
@@ -437,14 +437,14 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
      */
      (*o)->fabricated_disc_status= BURN_DISC_FULL;
 
-     /* This might be an overwriteable medium in a -ROM drive.
+     /* This might be an overwritable medium in a -ROM drive.
         Pitfall:
-        Multi-session media which bear a xorriso image for overwriteables
+        Multi-session media which bear a xorriso image for overwritables
         in their first session would get a TOC of that first image rather
         than of the medium.
         It is not possible to distinguish a BD-RE from a single session
-        BD-R with an image for overwriteables. But as soon as the medium
-        bears 2 logical tracks it cannot be overwriteable.
+        BD-R with an image for overwritables. But as soon as the medium
+        bears 2 logical tracks it cannot be overwritable.
         So count the number of tracks first.
      */
      disc= isoburn_toc_drive_get_disc(d);
@@ -463,7 +463,7 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
      isoburn_msgs_submit(*o, 0x00060000, msg, 0, "DEBUG", 0);
 
      if((flag & 16) || track_count >= 2) {
-       ret= 0; /* toc emulation off, or not overwriteable */
+       ret= 0; /* toc emulation off, or not overwritable */
      } else {
        ret= isoburn_start_emulation(*o, 1);
        if(ret<=0) {
@@ -524,14 +524,14 @@ ex:
 
 /**
     @param flag bit0= load
-                bit1= regard overwriteable media as blank
+                bit1= regard overwritable media as blank
                 bit2= if the drive is a regular disk file: truncate it to
                       the write start address
                 bit3= if the drive reports a -ROM profile then try to read 
                       table of content by scanning for ISO image headers.
                       (depending on media type and drive state this might 
                        help or it might make the resulting toc even worse)
-                bit4= do not emulate TOC on overwriteable media
+                bit4= do not emulate TOC on overwritable media
                 bit5= ignore ACL from external filesystems
                 bit6= ignore POSIX Extended Attributes from external filesystems
                 bit7= pretend -ROM profile and scan for table of content
@@ -1473,8 +1473,8 @@ int isoburn_emulate_toc(struct burn_drive *d, int flag)
      read_flag|= (1<<15)|((session_count>0)<<14);
    else {
 
-     /* growisofs aligns to 16 rather than 32. Overwriteable TOC emulation
-        relies on not accidentially seeing inter-session trash data.
+     /* growisofs aligns to 16 rather than 32. Overwritable TOC emulation
+        relies on not accidentally seeing inter-session trash data.
         But one can safely access 16 blocks earlier because a xorriso header
         would have been overwritten with the unused 16 blocks at its start.
         If libisoburn alignment would increase, then this would not be
