@@ -6,8 +6,8 @@
 /*
   libisofs related functions of libisoburn.
 
-  Copyright 2007 - 2017  Vreixo Formoso Lopes <metalpain2002@yahoo.es>
-                         Thomas Schmitt <scdbackup@gmx.net>
+  Copyright 2007 - 2009  Vreixo Formoso Lopes <metalpain2002@yahoo.es>
+  Copyright 2007 - 2020  Thomas Schmitt <scdbackup@gmx.net>
   Provided under GPL version 2 or later.
 */
 
@@ -275,6 +275,8 @@ displacement_rollover:;
  iso_read_opts_set_no_md5(ropts, int_num);
  if(read_opts->do_ecma119_map)
    iso_read_opts_set_ecma119_map(ropts, read_opts->map_mode);
+ if(read_opts->do_joliet_map)
+   iso_read_opts_set_joliet_map(ropts, read_opts->joliet_map_mode);
  iso_read_opts_set_new_inos(ropts, read_opts->noino);
 
  iso_read_opts_set_no_joliet(ropts, read_opts->nojoliet);
@@ -330,6 +332,8 @@ displacement_rollover:;
  read_opts->hasIso1999 = iso_read_image_features_has_iso1999(features);
  read_opts->hasElTorito = iso_read_image_features_has_eltorito(features);
  read_opts->size = iso_read_image_features_get_size(features);
+ read_opts->tree_loaded = iso_read_image_features_tree_loaded(features);
+ read_opts->rr_loaded = iso_read_image_features_rr_loaded(features);
  ret= 1;
 ex:;
  if(msg != NULL)
