@@ -1,7 +1,7 @@
 // Just to ensure we are C++-clean. This should not spit too much noise
 
 /* Copyright 2011 George Danchev <danchev@spnet.net>
- * Licensed under GNU GPL version 2
+ * Released into the public domain
  */
 
 #if __WORDSIZE == 32
@@ -12,13 +12,13 @@
 #include <iostream>
 #include <inttypes.h>
 
-extern "C" {
-#include <libburn/libburn.h>
-#include <libisofs/libisofs.h>
+//extern "C" {
+#include "libburn/libburn.h"
+#include "libisofs/libisofs.h"
 // using namespace burn;
 // (this was needed to before rev.4062 of libisoburn)
-#include <libisoburn/libisoburn.h>
-}
+#include "libisoburn/libisoburn.h"
+//}
 
 int main() {
    int major=-1, minor=-1, micro=-1;
