@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2014 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2019 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -85,7 +85,7 @@ handle_error:;
 handle_abort:;
      if(strcmp(lpt, link_path)!=0) {
        sprintf(xorriso->info_text,
-               "Problem occured with intermediate path : ");
+               "Problem occurred with intermediate path : ");
        Text_shellsafe(lpt, xorriso->info_text, 1);
        Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "NOTE", 0);
      }
@@ -343,6 +343,7 @@ int Xorriso_hop_link(struct XorrisO *xorriso, char *link_path,
 
 /* @param flag bit0= do not only sum up sizes but also print subdirs
                bit1= this is a recursion
+               bit2= do not report result by Xorriso_result()
    @return <=0 error , 1 ok , 2 could not open directory
 */
 int Xorriso_show_dux_subs(struct XorrisO *xorriso,
@@ -563,13 +564,15 @@ revoke_sorting:;
    report_size= sub_size/1024;
    if(report_size*1024<sub_size)
       report_size++;
-   if(xorriso->sh_style_result)
-     sprintf(xorriso->result_line, "%-7.f ",(double) (report_size));
-   else
-     sprintf(xorriso->result_line, "%7.f ",(double) (report_size));
-   sprintf(xorriso->result_line+strlen(xorriso->result_line), "%s\n",
-           Xorriso_esc_filepath(xorriso,show_path, sfe, 0));
-   Xorriso_result(xorriso, 0);
+   if(!(flag & 4)) {
+     if(xorriso->sh_style_result)
+       sprintf(xorriso->result_line, "%-7.f ",(double) (report_size));
+     else
+       sprintf(xorriso->result_line, "%7.f ",(double) (report_size));
+     sprintf(xorriso->result_line+strlen(xorriso->result_line), "%s\n",
+             Xorriso_esc_filepath(xorriso,show_path, sfe, 0));
+     Xorriso_result(xorriso, 0);
+   }
  }
 
  ret= 1;
@@ -902,7 +905,7 @@ int Xorriso_lsx_filev(struct XorrisO *xorriso, char *wd,
        if(ret<=0)
          link_target[0]= 0;
      }
-   } else if(flag&4) { /* -du or -dus */
+   } else if(flag&4) { /* -dux or -dusx */
      size= stbuf.st_size;
      if(S_ISDIR(stbuf.st_mode)) {
        ret= Xorriso_show_dux_subs(xorriso, path, filev[i], &size, boss_mem,
@@ -1186,7 +1189,7 @@ int Xorriso_findx_action(struct XorrisO *xorriso, struct FindjoB *job,
      ret= 1;
  } else if(action==18) { /* add_missing */
    ret= Xorriso_compare_2_files(xorriso, abs_path, iso_path, abs_path+dpl,
-                                &compare_result, 4|(1<<31));
+                                &compare_result, 4|(1u<<31));
    if(ret<xorriso->find_compare_result)
      xorriso->find_compare_result= ret;
    if(ret==0) {
@@ -1275,6 +1278,8 @@ int Xorriso_findx(struct XorrisO *xorriso, struct FindjoB *job,
  char *name= NULL, *path= NULL, *sfe= NULL;
  char *abs_dir_path_data= NULL, *abs_path= NULL;
 
+ job->depth= depth;
+
  if(xorriso->request_to_abort)
    {ret= 0; goto ex;}
 
@@ -1342,6 +1347,7 @@ int Xorriso_findx(struct XorrisO *xorriso, struct FindjoB *job,
  if(ret==0)
    {ret= 2; goto ex;}
  
+ job->depth++;
  while(!xorriso->request_to_abort) {
    Linkitem_reset_stack(&own_link_stack, link_stack, 0);
    ret= Dirseq_next_adr(dirseq,name,0);
@@ -1403,6 +1409,7 @@ int Xorriso_findx(struct XorrisO *xorriso, struct FindjoB *job,
 
  ret= 1;
 ex:;
+ job->depth= depth;
  Xorriso_free_meM(sfe);
  Xorriso_free_meM(name);
  Xorriso_free_meM(path);
