@@ -384,6 +384,7 @@ int Findjob_new(struct FindjoB **o, char *start_path, int flag)
  m->errmsg[0]= 0;
  m->errn= 0;
  m->match_count= 0;
+ m->depth= 0;
 
  ret= Exprnode_new(&(m->test_tree), m, NULL, "-find", (m->use_shortcuts)<<1);
  if(ret<=0)
@@ -752,7 +753,7 @@ int Findjob_endif(struct FindjoB *job, int flag)
  }
  if(job->cursor->up==NULL)
    goto improper_range;
- /* test wether parent node is -if */
+ /* test whether parent node is -if */
  job->cursor= job->cursor->up;
  Exprnode_get_branch(job->cursor, &true_branch, 0);
  if(!Exprnode_is_if(job->cursor,0) || true_branch == NULL) {
