@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2015 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2016 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -53,6 +53,8 @@ struct ExprtesT {
   22= -use_pattern char *arg1 ("on" [or "ls"], "off")
   23= -or_use_pattern char *arg1 ("on" [or "ls"], "off")
   24= -name_limit_blocker int *arg1
+  25= -maxdepth int *arg1
+  26= -mindepth int *arg1
  */
  int test_type;
 
@@ -176,11 +178,13 @@ struct FindjoB {
    52= show_stream_id
    53= internal: show_hfs_cmd , controlled by xorriso->show_hfs_cmd*
    54= internal: truncate_names
-   55= internal: unique_trunc_test lenght
+   55= internal: unique_trunc_test length
                  test for not uniquely truncatable names,
                  result delivered in XorrisO.find_unique_trunc_result
    56= like 54 but tolerating existing truncated names
    57= like 55 but tolerating existing truncated names
+   58= internal: last_data_file_block
+   59= set_to_mtime
  */
  int action;
  int prune;
@@ -199,6 +203,7 @@ struct FindjoB {
  off_t estim_upper_size;
  off_t estim_lower_size;
  struct FindjoB *subjob;
+ uint32_t last_data_file_block;
 
  /* Errors */
  char errmsg[4096];
@@ -214,6 +219,9 @@ struct FindjoB {
  /* Counts the test matches */
  unsigned long match_count;
 
+ /* Current depth of tree walking. Relative to start path. */
+ int depth;
+
 };
 
 
@@ -365,6 +373,9 @@ int Findjob_set_found_path(struct FindjoB *o, char *path, int flag);
 
 int Findjob_get_found_path(struct FindjoB *o, char **path, int flag);
 
+int Findjob_get_last_data_file_block(struct FindjoB *o, uint32_t *lba,
+                                     int flag);
+
 #else /* Xorriso_findjob_on_expR */
 
 
@@ -442,6 +453,9 @@ int Findjob_set_found_path(struct FindjoB *o, char *path, int flag);
 
 int Findjob_get_found_path(struct FindjoB *o, char **path, int flag);
 
+int Findjob_get_last_data_file_block(struct FindjoB *o, uint32_t *lba,
+                                     int flag);
+
 #endif /* ! Xorriso_findjob_on_expR */
 
 
