@@ -303,7 +303,7 @@ int Xorriso_fake_stbuf(struct XorrisO *xorriso, char *path, struct stat *stbuf,
 
  /* >>> With directories this should be : number of subdirs + 2 */
  /* >>> ??? How to obtain RR hardlink number for other types ? */
- /* This may get overriden farther down */
+ /* This may get overridden farther down */
  stbuf->st_nlink= 1;
 
  stbuf->st_uid= iso_node_get_uid(*node);
@@ -1296,7 +1296,8 @@ ex:
 int Xorriso_stream_type(struct XorrisO *xorriso, IsoNode *node,
                         IsoStream *stream, char type_text[], int flag)
 {
- int ret, lba;
+ int ret, lba, stream_type, block_size_log2;
+ uint8_t zisofs_algo[2], algo_num;
  char text[5];
 
  strncpy(text, stream->class->type, 4);
@@ -1307,10 +1308,16 @@ int Xorriso_stream_type(struct XorrisO *xorriso, IsoNode *node,
      strcpy(type_text, "image");
    else
      strcpy(type_text, "disk");
- } else if(strcmp(text, "ziso") == 0) {
-   strcpy(type_text, "--zisofs");
- } else if(strcmp(text, "osiz") == 0) {
-   strcpy(type_text, "--zisofs-decode");
+ } else if(strcmp(text, "ziso") == 0 || strcmp(text, "osiz") == 0) {
+   if(strcmp(text, "ziso") == 0)
+     strcpy(type_text, "--zisofs");
+   else
+     strcpy(type_text, "--zisofs-decode");
+   ret= iso_stream_get_zisofs_par(stream, &stream_type, zisofs_algo, &algo_num,
+                                  &block_size_log2, 0);
+   if(ret == 1)
+     sprintf(type_text + strlen(type_text), ":%c%c:%dk",
+             zisofs_algo[0], zisofs_algo[1], 1 << (block_size_log2 - 10));
  } else if(strcmp(text, "gzip") == 0) {
    strcpy(type_text, "--gzip");
  } else if(strcmp(text, "pizg") == 0) {
@@ -2078,7 +2085,7 @@ ex:;
 
 /* @param flag bit0= a match count !=1 is a FAILURE event
                bit1= with bit0 tolerate 0 matches if pattern is a constant
-               bit2= do not issue debug messages about temporay memory needs
+               bit2= do not issue debug messages about temporary memory needs
                bit3= do not add unresolved pattern to filev
 */
 int Xorriso_expand_pattern(struct XorrisO *xorriso,
@@ -2392,7 +2399,7 @@ int Xorriso_show_stream(struct XorrisO *xorriso, void *in_node,
  IsoFile *file;
  IsoStream *stream= NULL, *input_stream;
  IsoExternalFilterCommand *cmd;
- char type_text[16], *source_path= NULL;
+ char type_text[80], *source_path= NULL;
  unsigned int fs_id;
  dev_t dev_id;
  ino_t ino_id;
