@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2019 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2020 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -120,7 +120,7 @@ int Xorriso_startup_libraries(struct XorrisO *xorriso, int flag)
 {
  int ret, major, minor, micro;
  char *queue_sev, *print_sev, reason[1024];
- struct iso_zisofs_ctrl zisofs_ctrl= {0, 6, 15};
+ struct iso_zisofs_ctrl zisofs_ctrl;
 
 
 /* First an ugly compile time check for header version compatibility.
@@ -145,7 +145,7 @@ int Xorriso_startup_libraries(struct XorrisO *xorriso, int flag)
       error: 'INTENTIONAL_ABORT_OF_COMPILATION__HEADERFILE_libisoburn_dot_h_TOO_OLD__SEE_xorrisoburn_dot_c' undeclared (first use in this function)
       error: 'LIBISOBURN_MISCONFIGURATION_' undeclared (first use in this function)
 */
-/* The indendation is an advise of man gcc to help old compilers ignoring */
+/* The indentation is an advise of man gcc to help old compilers ignoring */
  #if xorriso_libisoburn_req_major > isoburn_header_version_major
  #define Isoburn_libisoburn_dot_h_too_olD 1
  #endif
@@ -213,13 +213,28 @@ LIBISOBURN_MISCONFIGURATION_ = 0;
  if(ret <= 0)
    return(ret);
 
+ memset(&zisofs_ctrl, 0, sizeof(zisofs_ctrl));
+ zisofs_ctrl.version = 1;
  ret = iso_zisofs_get_params(&zisofs_ctrl, 0);
  if (ret == 1) {
    xorriso->zisofs_block_size= xorriso->zisofs_block_size_default=
        (1 << zisofs_ctrl.block_size_log2);
    xorriso->zlib_level= xorriso->zlib_level_default=
        zisofs_ctrl.compression_level;
+   xorriso->zisofs_v2_enabled= zisofs_ctrl.v2_enabled;
+   xorriso->zisofs_max_total_blocks=
+     xorriso->zisofs_max_total_blocks_default= zisofs_ctrl.max_total_blocks;
+   xorriso->zisofs_max_file_blocks=
+     xorriso->zisofs_max_file_blocks_default= zisofs_ctrl.max_file_blocks;
+   xorriso->zisofs_v2_block_size= xorriso->zisofs_v2_block_size_default=
+       1 << zisofs_ctrl.v2_block_size_log2;
+   xorriso->zisofs_block_number_target= zisofs_ctrl.block_number_target;
+   xorriso->zisofs_bpt_discard_free_ratio=
+   xorriso->zisofs_bpt_discard_free_ratio_default=
+       zisofs_ctrl.bpt_discard_free_ratio;
  }
+ xorriso->zisofs_susp_z2= xorriso->zisofs_susp_z2_default=
+     iso_zisofs_ctrl_susp_z2(-1);
 
  iso_node_xinfo_make_clonable(Xorriso__mark_update_xinfo,
                               Xorriso__mark_update_cloner, 0);
@@ -765,8 +780,10 @@ int Xorriso_jigdo_interpreter(struct XorrisO *xorriso, char *aspect, char *arg,
      goto jte_failed;
    xorriso->libjte_params_given|= 8;
  } else if(strcmp(aspect, "md5_path") == 0 ||
-           strcmp(aspect, "-md5-list") == 0) {
-   ret= libjte_set_md5_path(jte, arg);
+           strcmp(aspect, "-md5-list") == 0 ||
+           strcmp(aspect, "checksum_path") == 0 ||
+           strcmp(aspect, "-checksum-list") == 0) {
+   ret= libjte_set_checksum_path(jte, arg);
    if(ret <= 0)
      goto jte_failed;
    xorriso->libjte_params_given|= 16;
@@ -802,8 +819,10 @@ int Xorriso_jigdo_interpreter(struct XorrisO *xorriso, char *aspect, char *arg,
      goto jte_failed;
    xorriso->libjte_params_given|= 512;
  } else if(strcmp(aspect, "demand_md5") == 0 ||
-           strcmp(aspect, "-jigdo-force-md5") == 0) {
-   ret= libjte_add_md5_demand(jte, arg);
+           strcmp(aspect, "-jigdo-force-md5") == 0 ||
+           strcmp(aspect, "demand_checksum") == 0 ||
+           strcmp(aspect, "-jigdo-force-checksum") == 0) {
+   ret= libjte_add_checksum_demand(jte, arg);
    if(ret <= 0)
      goto jte_failed;
    xorriso->libjte_params_given|= 1024;
@@ -813,6 +832,13 @@ int Xorriso_jigdo_interpreter(struct XorrisO *xorriso, char *aspect, char *arg,
    if(ret <= 0)
      goto jte_failed;
    xorriso->libjte_params_given|= 2048;
+ } else if(strcmp(aspect, "checksum_algorithm") == 0 ||
+           strcmp(aspect, "-jigdo-checksum-algorithm") == 0) {
+   int ck_size;
+   ret= libjte_set_checksum_algorithm(jte, arg, &ck_size);
+   if(ret <= 0)
+     goto jte_failed;
+   xorriso->libjte_params_given|= 4096;
  } else {
    sprintf(xorriso->info_text, "-jigdo: unknown aspect '%s'", aspect); 
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
