@@ -4,14 +4,16 @@
 # from base file xorriso/xorriso.texi.
 # Same for xorriso/xorrisofs.texi and xorriso/xorrecord.texi.
 
-( cd xorriso ; makeinfo ./xorriso.texi )
-( cd xorriso ; makeinfo ./xorrisofs.texi )
-( cd xorriso ; makeinfo ./xorrecord.texi )
-( cd xorriso ; makeinfo ./xorriso-tcltk.texi )
+( cd xorriso ; makeinfo --no-split ./xorriso.texi )
+( cd xorriso ; makeinfo --no-split ./xorrisofs.texi )
+( cd xorriso ; makeinfo --no-split ./xorrecord.texi )
+( cd xorriso ; makeinfo --no-split ./xorriso-tcltk.texi )
+( cd xorriso-dd-target ; makeinfo --no-split ./xorriso-dd-target.texi )
 
 xorriso/make_xorriso_1 -auto
 xorriso/make_xorriso_1 -auto -xorrisofs
 xorriso/make_xorriso_1 -auto -xorrecord
 xorriso/make_xorriso_1 -auto -xorriso-tcltk
+xorriso/make_xorriso_1 -auto -xorriso-dd-target
 
 
