@@ -113,8 +113,7 @@ int Xorriso_prepare_regex(struct XorrisO *xorriso, char *adr, int flag)
 
        if(adr_part[0]==0)
          goto next_adr_part;
-       if(adr_part[0]=='.' && adr_part[1]==0 &&
-          (xorriso->re_fill>0 || i<count-1))
+       if(adr_part[0] == '.' && adr_part[1] == 0)
          goto next_adr_part;
        if(adr_part[0]=='.' && adr_part[1]=='.' && adr_part[2]==0) {
          /* delete previous part */
@@ -159,6 +158,12 @@ next_adr_part:;
        Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE",0);
        {ret= 0; goto ex;}
      }
+     if(xorriso->re_fill == 0 && is_still_relative) {
+       /* "." and its equivalents end up here */
+       if(Sregex_string(&(xorriso->re_constants[0]), ".", 0) <=0)
+         {ret= -1; goto ex;}  
+       xorriso->re_fill= 1;
+     }
 
      Xorriso__bourne_to_reg(adr_start,xorriso->reg_expr,0); /* just for show */
 
