@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2019 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2020 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -103,6 +103,22 @@ int Xorriso_option_joliet(struct XorrisO *xorriso, char *mode, int flag)
 }
 
 
+/* Command -joliet_map */
+int Xorriso_option_joliet_map(struct XorrisO *xorriso, char *mode, int flag)
+{
+ if(strcmp(mode, "unmapped") == 0) {
+   xorriso->joliet_map= 0;
+ } else if(strcmp(mode, "stripped") == 0) {
+   xorriso->joliet_map= 1;
+ } else {
+   sprintf(xorriso->info_text, "-joliet_map: unknown mode '%s'", mode);
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
+   return(0);
+ }
+ return(1);
+}
+
+
 /* Command -launch_frontend */
 int Xorriso_option_launch_frontend(struct XorrisO *xorriso,
                                    int argc, char **argv, int *idx, int flag)
@@ -1746,6 +1762,7 @@ int Xorriso_option_osirrox(struct XorrisO *xorriso, char *mode, int flag)
 {
  int l, allow_restore;
  char *npt, *cpt;
+ double num= 0.0;
 
  allow_restore= xorriso->allow_restore;
 
@@ -1792,7 +1809,29 @@ int Xorriso_option_osirrox(struct XorrisO *xorriso, char *mode, int flag)
      xorriso->do_strict_acl|= 1;
    else if(strncmp(cpt, "strict_acl_off", l)==0 && l >= 14)
      xorriso->do_strict_acl&= ~1;
-   else {
+   else if(strncmp(cpt, "check_md5_on", l) == 0 && l >= 12) {
+     xorriso->do_md5|= 1 << 6;
+     xorriso->do_md5&= ~(2 << 6);
+   } else if(strncmp(cpt, "check_md5_force", l)==0 && l >= 15) {
+     xorriso->do_md5|= 3 << 6;
+   } else if(strncmp(cpt, "check_md5_off", l)==0 && l >= 13) {
+     xorriso->do_md5&= ~(3 << 6);
+   } else if(strncmp(cpt, "sparse=", 7) == 0 && l >= 7) {
+     if(strncmp(cpt + 7, "off", 3) == 0 && l == 10) {
+       num= 0.0;
+     } else {
+       Xorriso__parse_size_param(cpt, 7, l, &num);
+       if(num < 1.0)
+         num= 0.0;
+       if(num > 1.0 * 1024.0 * 1024.0 * 1024.0) {
+         strcpy(xorriso->info_text,
+                "osirrox sparse= too large (allowed: off, 1 to 1g)");
+         Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+         return(0);
+       }
+     }
+     xorriso->sparse_min_gap= num;
+   } else {
 unknown_mode:;
      sprintf(xorriso->info_text, "-osirrox: unknown mode '%s'", cpt);
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
