@@ -4,7 +4,7 @@
    a command line oriented batch and dialog tool which creates, loads,
    manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2019 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2021 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -19,7 +19,7 @@
 */
 #define xorriso_libisoburn_req_major  1
 #define xorriso_libisoburn_req_minor  5
-#define xorriso_libisoburn_req_micro  2
+#define xorriso_libisoburn_req_micro  4
 
 
 struct SpotlisT;          /* List of intervals with different read qualities */
@@ -34,8 +34,8 @@ int Xorriso_detach_libraries(struct XorrisO *xorriso, int flag);
 
 int Xorriso_create_empty_iso(struct XorrisO *xorriso, int flag);
 
-/* @param flag bit0=aquire as isoburn input drive
-               bit1=aquire as libburn output drive (as isoburn drive if bit0)
+/* @param flag bit0=acquire as isoburn input drive
+               bit1=acquire as libburn output drive (as isoburn drive if bit0)
    @return <=0 failure , 1=success , 2=neither readable or writeable
 */
 int Xorriso_aquire_drive(struct XorrisO *xorriso, char *adr, char *show_adr,
@@ -172,6 +172,8 @@ int Xorriso_normalize_img_path(struct XorrisO *xorriso, char *wd,
 
 /* @param boss_iter Opaque handle to be forwarded to actions in ISO image
                     Set to NULL if calling this function from outside ISO world
+   @param flag      bit0= silently ignore attempt of renaming to same path
+                          and return 2
 */
 int Xorriso_rename(struct XorrisO *xorriso, void *boss_iter,
                    char *origin, char *dest, int flag);
@@ -338,6 +340,9 @@ int Xorriso_update_iso_lba0(struct XorrisO *xorriso, int iso_lba, int isosize,
                             char *head_buffer, struct CheckmediajoB *job,
                             int flag);
 
+int Xorriso_truncate_overwritable(struct XorrisO *xorriso, char *adr_mode,
+                                  char *adr_value, char *adjust, int flag);
+
 int Xorriso_get_local_charset(struct XorrisO *xorriso, char **name, int flag);
 
 int Xorriso_set_local_charset(struct XorrisO *xorriso, char *name, int flag);
@@ -375,6 +380,8 @@ int Xorriso_extract_cut(struct XorrisO *xorriso,
                         char *img_path, char *disk_path,
                         off_t img_offset, off_t bytes, int flag);
 
+int Xorriso_extract_boot_images(struct XorrisO *xorriso, char *disk_dir_path,
+                                int flag);
 
 int Xorriso_relax_compliance(struct XorrisO *xorriso, char *mode,
                                     int flag);
@@ -637,6 +644,9 @@ int Xorriso_apply_sort_file(struct XorrisO *xorriso, char *path, int flag);
 
 int Xorriso_report_system_area(struct XorrisO *xorriso, char *form, int flag);
 
+int Xorriso_list_boot_images(struct XorrisO *xorriso,
+                             char ***imgs, int *img_count, int flag);
+
 int Xorriso_external_filter_banned(struct XorrisO *xorriso, char *purpose,
                                    int flag);
 
@@ -663,5 +673,8 @@ int Xorriso_make_guid(struct XorrisO *xorriso, char *line, int flag);
 
 int Xorriso_set_libisofs_now(struct XorrisO *xorriso, int flag);
 
+int Xorriso_obtain_indev_readsize(struct XorrisO *xorriso, uint32_t *blocks,
+                                  int flag);
+
 #endif /* Xorrisoburn_includeD */
 
